/*
 * exports.h - internal header with definitions of all exported functions
 *
 * Copyright (C) 2018 Thorsten Otto
 *
 * For conditions of distribution and use, see the accompanying README file.
 */

#ifndef JPEG_LIB_VERSION
 #error "JPEG_LIB_VERSION not defined"
#endif

#ifndef LIBFUNC
# error "LIBFUNC must be defined before including this file"
#endif
#ifndef LIBFUNC2
#define LIBFUNC2(_fn, name, _nargs) LIBFUNC(_fn, name, _nargs)
#endif

	LIBFUNC(0, jpeglib_slb_control, 2)
	LIBFUNC(1, jpeg_std_error, 1)
	LIBFUNC(2, jpeg_CreateCompress, 3)
	LIBFUNC(3, jpeg_CreateDecompress, 3)
	LIBFUNC(4, jpeg_destroy_compress, 1)
	LIBFUNC(5, jpeg_destroy_decompress, 1)
	LIBFUNC(6, jpeg_stdio_dest, 2)
	LIBFUNC(7, jpeg_stdio_src, 2)
#if JPEG_LIB_VERSION >= 80 || defined(MEM_SRCDST_SUPPORTED)
	LIBFUNC(8, jpeg_mem_dest, 3)
	LIBFUNC(9, jpeg_mem_src, 3)
#else
	NOFUNC
	NOFUNC
#endif

	LIBFUNC(10, jpeg_set_defaults, 1)
	LIBFUNC(11, jpeg_set_colorspace, 2)
	LIBFUNC(12, jpeg_default_colorspace, 1)
	LIBFUNC(13, jpeg_set_quality, 3)
	LIBFUNC(14, jpeg_set_linear_quality, 3)
#if JPEG_LIB_VERSION >= 70
	LIBFUNC(15, jpeg_default_qtables, 2)
#else
	NOFUNC
#endif
	LIBFUNC(16, jpeg_add_quant_table, 5)
	LIBFUNC(17, jpeg_quality_scaling, 1)
	LIBFUNC(18, jpeg_simple_progression, 1)
	LIBFUNC(19, jpeg_suppress_tables, 2)
	LIBFUNC(20, jpeg_alloc_quant_table, 1)
	LIBFUNC(21, jpeg_alloc_huff_table, 1)
	LIBFUNC(22, jpeg_start_compress, 2)
	LIBFUNC(23, jpeg_write_scanlines, 3)
	LIBFUNC(24, jpeg_finish_compress, 1)
#if JPEG_LIB_VERSION >= 70
	LIBFUNC(25, jpeg_calc_jpeg_dimensions, 1)
#else
	NOFUNC
#endif
	LIBFUNC(26, jpeg_write_raw_data, 3)
	LIBFUNC(27, jpeg_write_marker, 4)
	LIBFUNC(28, jpeg_write_m_header, 3)
	LIBFUNC(29, jpeg_write_m_byte, 2)
	LIBFUNC(30, jpeg_write_tables, 1)
	LIBFUNC(31, jpeg_read_header, 2)
	LIBFUNC(32, jpeg_start_decompress, 1)
	LIBFUNC(33, jpeg_read_scanlines, 3)
	LIBFUNC(34, jpeg_finish_decompress, 1)
	LIBFUNC(35, jpeg_read_raw_data, 3)
	LIBFUNC(36, jpeg_has_multiple_scans, 1)
	LIBFUNC(37, jpeg_start_output, 2)
	LIBFUNC(38, jpeg_finish_output, 1)
	LIBFUNC(39, jpeg_input_complete, 1)
	LIBFUNC(40, jpeg_new_colormap, 1)
	LIBFUNC(41, jpeg_consume_input, 1)
#if JPEG_LIB_VERSION >= 80
	LIBFUNC(42, jpeg_core_output_dimensions, 1)
#else
	NOFUNC
#endif
	LIBFUNC(43, jpeg_calc_output_dimensions, 1)
	LIBFUNC(44, jpeg_save_markers, 3)
	LIBFUNC(45, jpeg_set_marker_processor, 3)
	LIBFUNC(46, jpeg_read_coefficients, 1)
	LIBFUNC(47, jpeg_write_coefficients, 2)
	LIBFUNC(48, jpeg_copy_critical_parameters, 2)
	LIBFUNC(49, jpeg_abort_compress, 1)
	LIBFUNC(50, jpeg_abort_decompress, 1)
	LIBFUNC(51, jpeg_abort, 1)
	LIBFUNC(52, jpeg_destroy, 1)
	LIBFUNC(53, jpeg_resync_to_restart, 2)
	LIBFUNC(54, jpeg_reset_huff_decode, 2)

	LIBFUNC(55, jpeg_write_icc_profile, 3)
	LIBFUNC(56, jpeg_skip_scanlines, 2)
	LIBFUNC(57, jpeg_crop_scanline, 3)
	LIBFUNC(58, jpeg_read_icc_profile, 3)

/*
 * These functions are not part of the API,
 * but are needed by the tools
 */

	LIBFUNC(59, jround_up, 2)
	LIBFUNC(60, jcopy_block_row, 3)
	LIBFUNC(61, jdiv_round_up, 2)
	
/*
 * TurboJPEG API
 */
#if defined(LIBJPEG_TURBO_VERSION_NUMBER)
	LIBFUNC(62, tjInitCompress, 0)
	LIBFUNC(63, tjCompress2, 11)
	LIBFUNC(64, tjCompressFromYUV, 10)
	LIBFUNC(65, tjCompressFromYUVPlanes, 10)
	LIBFUNC(66, tjBufSize, 3)
	LIBFUNC(67, tjBufSizeYUV2, 3)
	LIBFUNC(68, tjPlaneSizeYUV, 5)
	LIBFUNC(69, tjPlaneWidth, 3)
	LIBFUNC(70, tjPlaneHeight, 3)
	LIBFUNC(71, tjEncodeYUV3, 10)
	LIBFUNC(72, tjEncodeYUVPlanes, 10)
	LIBFUNC(73, tjInitDecompress, 0)
	LIBFUNC(74, tjDecompressHeader3, 7)
	LIBFUNC(75, tjGetScalingFactors, 1)
	LIBFUNC(76, tjDecompress2, 9)
	LIBFUNC(77, tjDecompressToYUV2, 8)
	LIBFUNC(78, tjDecompressToYUVPlanes, 8)
	LIBFUNC(79, tjDecodeYUV, 10)
	LIBFUNC(80, tjDecodeYUVPlanes, 10)
	LIBFUNC(81, tjInitTransform, 0)
	LIBFUNC(82, tjTransform, 8)
	LIBFUNC(83, tjDestroy, 1)
	LIBFUNC(84, tjAlloc, 1)
	LIBFUNC(85, tjFree, 1)
	LIBFUNC(86, tjGetErrorStr, 0)
	LIBFUNC(87, TJBUFSIZE, 2)
	LIBFUNC(88, TJBUFSIZEYUV, 3)
	LIBFUNC(89, tjBufSizeYUV, 3)
	LIBFUNC(90, tjCompress, 11)
	LIBFUNC(91, tjEncodeYUV, 9)
	LIBFUNC(92, tjEncodeYUV2, 9)
	LIBFUNC(93, tjDecompressHeader, 5)
	LIBFUNC(94, tjDecompressHeader2, 6)
	LIBFUNC(95, tjDecompress, 9)
	LIBFUNC(96, tjDecompressToYUV, 5)
#else
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
#endif

#if defined(LIBJPEG_TURBO_VERSION_NUMBER) && LIBJPEG_TURBO_VERSION_NUMBER >= 2000000L
	LIBFUNC(97, tjLoadImage, 6)
	LIBFUNC(98, tjSaveImage, 6)
	LIBFUNC(99, tjGetErrorStr2, 1)
	LIBFUNC(100, tjGetErrorCode, 1)
#else
	NOFUNC
	NOFUNC
	NOFUNC
	NOFUNC
#endif

#undef LIBFUNC
#undef LIBFUNC2
#undef NOFUNC
